@@ -10,9 +10,9 @@ import (
 func TestAnalyzer(t *testing.T) {
 	testdata := analysistest.TestData()
 
-	t.Run("mixed arguments", func(t *testing.T) {
+	t.Run("no mixed arguments", func(t *testing.T) {
 		analyzer := sloglint.New(nil)
-		analysistest.Run(t, testdata, analyzer, "mixed_args")
+		analysistest.Run(t, testdata, analyzer, "no_mixed_args")
 	})
 
 	t.Run("key-value pairs only", func(t *testing.T) {
@@ -25,11 +25,26 @@ func TestAnalyzer(t *testing.T) {
 		analysistest.Run(t, testdata, analyzer, "attr_only")
 	})
 
+	t.Run("context only", func(t *testing.T) {
+		analyzer := sloglint.New(&sloglint.Options{ContextOnly: true})
+		analysistest.Run(t, testdata, analyzer, "context_only")
+	})
+
+	t.Run("static message", func(t *testing.T) {
+		analyzer := sloglint.New(&sloglint.Options{StaticMsg: true})
+		analysistest.Run(t, testdata, analyzer, "static_msg")
+	})
+
 	t.Run("no raw keys", func(t *testing.T) {
 		analyzer := sloglint.New(&sloglint.Options{NoRawKeys: true})
 		analysistest.Run(t, testdata, analyzer, "no_raw_keys")
 	})
 
+	t.Run("key naming case", func(t *testing.T) {
+		analyzer := sloglint.New(&sloglint.Options{KeyNamingCase: "snake"})
+		analysistest.Run(t, testdata, analyzer, "key_naming_case")
+	})
+
 	t.Run("arguments on separate lines", func(t *testing.T) {
 		analyzer := sloglint.New(&sloglint.Options{ArgsOnSepLines: true})
 		analysistest.Run(t, testdata, analyzer, "args_on_sep_lines")
